@@ -1,8 +1,9 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 
-#include <QtCore>;
-#include <QCoreApplication>;
+#include <QtCore>
+#include <QCoreApplication>
+#include "dabout.h"
 
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindow)
@@ -169,6 +170,9 @@ void MainWindow::downloadFinished(QNetworkReply *reply)
 	ui->plainTextEdit->hide();
 	//ui->edtSong->setText("Downloaded");
 
+	ui->btnDownload->setEnabled(true);
+	ui->label->setVisible(false);
+	delete movie;
     }
     else{
 	ui->edtSong->setText(reply->header(QNetworkRequest::ContentTypeHeader).toString());
@@ -182,5 +186,26 @@ void MainWindow::on_btnDownload_clicked()
     if (ui->lstItems->currentRow()>-1){
 	    ui->plainTextEdit->show();
 	    download("http://www.goear.com/tracker758.php?f="+links->at(ui->lstItems->currentRow()));
+
+	    ui->label->setVisible(true);
+	    movie = new QMovie(":/loading.gif");
+
+	    if (movie->isValid()){
+		ui->label->setMovie(movie);
+		movie->start();
+	    }else{
+		ui->label->setPixmap(QPixmap(":/loading.gif"));
+	    }
+
+	    ui->btnDownload->setDisabled(true);
+
 	}
 }
+
+void MainWindow::on_actionAbout_triggered()
+{
+    DAbout *dAbout;
+    dAbout=new DAbout(0);
+    dAbout->exec();
+    delete dAbout;
+}
