@@ -7,6 +7,7 @@
 #include <QtXml>
 #include <QTextBlock>
 #include <QFileDialog>
+#include <QMovie>
 
 
 namespace Ui {
@@ -34,11 +35,14 @@ private slots:
     void download(QString item);
     void downloadFinished(QNetworkReply *reply);
 
+    void on_actionAbout_triggered();
+
 private:
     Ui::MainWindow *ui;
     QNetworkAccessManager *netAccessMan;
     QByteArray downloadedItem;
     QStringList *links;
+    QMovie *movie;
 };
 
 #endif // MAINWINDOW_H
